==> DateTime-Locale-1.20.tar.gz: DateTime-Locale-1.20/share/nn.pl <==
{
  am_pm_abbreviated => [
    "f.m.",
    "e.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L.",
    MEd => "E d.M",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    "MMMMW-count-one" => "'veke' W 'i' MMM",
    "MMMMW-count-other" => "'veke' W 'i' MMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "d.M.",
    Md => "d.M.",
    d => "d.",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.M.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'veke' w 'i' Y",
    "yw-count-other" => "'veke' w 'i' Y",
  },
  code => "nn",
  date_format_full => "EEEE d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "m\N{U+00e5}.",
    "ty.",
    "on.",
    "to.",
    "fr.",
    "la.",
    "s\N{U+00f8}.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "m\N{U+00e5}ndag",
    "tysdag",
    "onsdag",
    "torsdag",
    "fredag",
    "laurdag",
    "s\N{U+00f8}ndag",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+00e5}n",
    "tys",
    "ons",
    "tor",
    "fre",
    "lau",
    "s\N{U+00f8}n",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "m\N{U+00e5}ndag",
    "tysdag",
    "onsdag",
    "torsdag",
    "fredag",
    "laurdag",
    "s\N{U+00f8}ndag",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_wide => [
    "f.Kr.",
    "e.Kr.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Norwegian Nynorsk",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mars",
    "apr.",
    "mai",
    "juni",
    "juli",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  name => "Norwegian Nynorsk",
  native_language => "nynorsk",
  native_name => "nynorsk",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "'kl'. HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}

==> DateTime-Locale-1.24.tar.gz: DateTime-Locale-1.24/share/nn.pl <==
{
  am_pm_abbreviated => [
    "f.m.",
    "e.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L.",
    MEd => "E d.M",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    "MMMMW-count-one" => "'veke' W 'i' MMMM",
    "MMMMW-count-other" => "'veke' W 'i' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "d.M.",
    Md => "d.M.",
    d => "d.",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.M.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'veke' w 'i' Y",
    "yw-count-other" => "'veke' w 'i' Y",
  },
  code => "nn",
  date_format_full => "EEEE d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "m\N{U+00e5}.",
    "ty.",
    "on.",
    "to.",
    "fr.",
    "la.",
    "s\N{U+00f8}.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "m\N{U+00e5}ndag",
    "tysdag",
    "onsdag",
    "torsdag",
    "fredag",
    "laurdag",
    "s\N{U+00f8}ndag",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+00e5}n",
    "tys",
    "ons",
    "tor",
    "fre",
    "lau",
    "s\N{U+00f8}n",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "m\N{U+00e5}ndag",
    "tysdag",
    "onsdag",
    "torsdag",
    "fredag",
    "laurdag",
    "s\N{U+00f8}ndag",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_wide => [
    "f.Kr.",
    "e.Kr.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Norwegian Nynorsk",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mars",
    "apr.",
    "mai",
    "juni",
    "juli",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  name => "Norwegian Nynorsk",
  native_language => "nynorsk",
  native_name => "nynorsk",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "'kl'. HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
